@@ -17,7 +17,6 @@ import sys
 import zlib
 from threading import get_ident as get_thread_id
 
-from .debug import NoDebugging
 from .debug import SimpleReprMixin
 from .misc import CoverageException
 from .misc import file_be_gone
@@ -185,8 +184,7 @@ class CoverageData(SimpleReprMixin):
                  basename=None,
                  suffix=None,
                  no_disk=False,
-                 warn=None,
-                 debug=None):
+                 warn=None):
         """Create a :class:`CoverageData` object to hold coverage-measured data.
 
         Arguments:
@@ -205,7 +203,6 @@ class CoverageData(SimpleReprMixin):
         self._basename = os.path.abspath(basename or ".coverage")
         self._suffix = suffix
         self._warn = warn
-        self._debug = debug or NoDebugging()
 
         self._choose_filename()
         self._file_map = {}
@@ -248,9 +245,7 @@ class CoverageData(SimpleReprMixin):
 
         Initializes the schema and certain metadata.
         """
-        if self._debug.should('dataio'):
-            self._debug.write("Creating data file {!r}".format(self._filename))
-        self._dbs[get_thread_id()] = db = SqliteDb(self._filename, self._debug)
+        self._dbs[get_thread_id()] = db = SqliteDb(self._filename)
         with db:
             db.executescript(SCHEMA)
             db.execute("insert into coverage_schema (version) values (?)",
@@ -266,9 +261,7 @@ class CoverageData(SimpleReprMixin):
 
     def _open_db(self):
         """Open an existing db file, and read its metadata."""
-        if self._debug.should('dataio'):
-            self._debug.write("Opening data file {!r}".format(self._filename))
-        self._dbs[get_thread_id()] = SqliteDb(self._filename, self._debug)
+        self._dbs[get_thread_id()] = SqliteDb(self._filename)
         self._read_db()
 
     def _read_db(self):
@@ -279,15 +272,13 @@ class CoverageData(SimpleReprMixin):
                     "select version from coverage_schema")
             except Exception as exc:
                 raise CoverageException(
-                    "Data file {!r} doesn't seem to be a coverage data "
-                    "file: {}".format(self._filename, exc))
+                    f"Data file {self._filename!r} doesn't seem to be a coverage "
+                    f"data file: {exc}")
             else:
                 if schema_version != SCHEMA_VERSION:
                     raise CoverageException(
-                        "Couldn't use data file {!r}: wrong schema: {} instead "
-                        "of {}".format(self._filename,
-                                       schema_version,
-                                       SCHEMA_VERSION))
+                        f"Couldn't use data file {self._filename!r}: wrong "
+                        f"schema: {schema_version} instead of {SCHEMA_VERSION}")
 
             for row in db.execute("select value from meta where key = 'has_arcs'"):
                 self._has_arcs = bool(int(row[0]))
@@ -330,10 +321,6 @@ class CoverageData(SimpleReprMixin):
         .. versionadded:: 5.0
 
         """
-        if self._debug.should('dataio'):
-            self._debug.write(
-                "Dumping data from data file {!r}".format(
-                    self._filename))
         with self._connect() as con:
             return b'z' + zlib.compress(con.dump())
 
@@ -349,17 +336,12 @@ class CoverageData(SimpleReprMixin):
         .. versionadded:: 5.0
 
         """
-        if self._debug.should('dataio'):
-            self._debug.write(
-                "Loading data into data file {!r}".format(
-                    self._filename))
         if data[:1] != b'z':
             raise CoverageException(
-                "Unrecognized serialization: {!r} (head of {} bytes)".format(
-                    data[:40],
-                    len(data)))
+                f"Unrecognized serialization: {data[:40]!r} (head of "
+                f"{len(data)} bytes)")
         script = zlib.decompress(data[1:])
-        self._dbs[get_thread_id()] = db = SqliteDb(self._filename, self._debug)
+        self._dbs[get_thread_id()] = db = SqliteDb(self._filename)
         with db:
             db.executescript(script)
         self._read_db()
@@ -401,8 +383,6 @@ class CoverageData(SimpleReprMixin):
         .. versionadded:: 5.0
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Setting context: %r" % (context,))
         self._current_context = context
         self._current_context_id = None
 
@@ -442,10 +422,6 @@ class CoverageData(SimpleReprMixin):
             { filename: { lineno: None, ... }, ...}
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Adding lines: %d files, %d lines total" % (
-                len(line_data), sum(len(lines) for lines in line_data.values())
-            ))
         self._start_using()
         self._choose_lines_or_arcs(lines=True)
         if not line_data:
@@ -469,10 +445,6 @@ class CoverageData(SimpleReprMixin):
             { filename: { (l1,l2): None, ... }, ...}
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Adding arcs: %d files, %d arcs total" % (
-                len(arc_data), sum(len(arcs) for arcs in arc_data.values())
-            ))
         self._start_using()
         self._choose_lines_or_arcs(arcs=True)
         if not arc_data:
@@ -512,8 +484,6 @@ class CoverageData(SimpleReprMixin):
         `file_tracers` is { filename: plugin_name, ... }
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Adding file tracers: %d files" % (len(file_tracers),))
         if not file_tracers:
             return
         self._start_using()
@@ -522,17 +492,15 @@ class CoverageData(SimpleReprMixin):
                 file_id = self._file_id(filename)
                 if file_id is None:
                     raise CoverageException(
-                        "Can't add file tracer data for unmeasured file '%s'" % (
-                            filename,))
+                        f"Can't add file tracer data for unmeasured file "
+                        f"'{filename}'")
 
                 existing_plugin = self.file_tracer(filename)
                 if existing_plugin:
                     if existing_plugin != plugin_name:
                         raise CoverageException(
-                            "Conflicting file tracer name for '%s': %r vs %r" % (
-                                filename, existing_plugin, plugin_name,
-                            )
-                        )
+                            f"Conflicting file tracer name for '{filename}': "
+                            f"{existing_plugin} vs {plugin_name}")
                 elif plugin_name:
                     con.execute(
                         "insert into tracer (file_id, tracer) values (?, ?)",
@@ -554,8 +522,6 @@ class CoverageData(SimpleReprMixin):
         files. It is used to associate the right filereporter, etc.
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Touching %r" % (filenames,))
         self._start_using()
         with self._connect(): # Use this to get one transaction.
             if not self._has_arcs and not self._has_lines:
@@ -575,10 +541,6 @@ class CoverageData(SimpleReprMixin):
         re-map paths to match the local machine's.
 
         """
-        if self._debug.should('dataop'):
-            self._debug.write("Updating with data from %r" % (
-                getattr(other_data, '_filename', '???'),
-            ))
         if self._has_lines and other_data._has_arcs:
             raise CoverageException("Can't combine arc data with line data")
         if self._has_arcs and other_data._has_lines:
@@ -679,10 +641,8 @@ class CoverageData(SimpleReprMixin):
                 # If there is no tracer, there is always the None tracer.
                 if this_tracer is not None and this_tracer != other_tracer:
                     raise CoverageException(
-                        "Conflicting file tracer name for '%s': %r vs %r" % (
-                            path, this_tracer, other_tracer
-                        )
-                    )
+                        f"Conflicting file tracer name for '{path}': {this_tracer} "
+                        f"vs {other_tracer}")
                 tracer_map[path] = other_tracer
 
             # Prepare arc and line rows to be inserted by converting the file
@@ -746,17 +706,12 @@ class CoverageData(SimpleReprMixin):
         self._reset()
         if self._no_disk:
             return
-        if self._debug.should('dataio'):
-            self._debug.write("Erasing data file {!r}".format(self._filename))
         file_be_gone(self._filename)
         if parallel:
             data_dir, local = os.path.split(self._filename)
             localdot = local + '.*'
             pattern = os.path.join(os.path.abspath(data_dir), localdot)
             for filename in glob.glob(pattern):
-                if self._debug.should('dataio'):
-                    self._debug.write(
-                        "Erasing parallel data file {!r}".format(filename))
                 file_be_gone(filename)
 
     def read(self):
@@ -977,7 +932,7 @@ class CoverageData(SimpleReprMixin):
         Returns a list of (key, value) pairs.
 
         """
-        with SqliteDb(":memory:", debug=NoDebugging()) as db:
+        with SqliteDb(":memory:") as db:
             temp_store = [row[0] for row in db.execute("pragma temp_store")]
             compile_options = [row[0] for row in db.execute("pragma compile_options")]
 
@@ -999,8 +954,7 @@ class SqliteDb(SimpleReprMixin):
             db.execute("insert into schema (version) values (?)", (SCHEMA_VERSION,))
 
     """
-    def __init__(self, filename, debug):
-        self.debug = debug if debug.should('sql') else None
+    def __init__(self, filename):
         self.filename = filename
         self.nest = 0
         self.con = None
@@ -1020,8 +974,6 @@ class SqliteDb(SimpleReprMixin):
         # effectively causing a nested context. However, given the idempotent
         # nature of the tracer operations, sharing a connection among threads
         # is not a problem.
-        if self.debug:
-            self.debug.write("Connecting to {!r}".format(self.filename))
         self.con = sqlite3.connect(filename, check_same_thread=False)
         self.con.create_function('REGEXP', 2, _regexp)
 
@@ -1050,19 +1002,11 @@ class SqliteDb(SimpleReprMixin):
     def __exit__(self, exc_type, exc_value, traceback):
         self.nest -= 1
         if self.nest == 0:
-            try:
-                self.con.__exit__(exc_type, exc_value, traceback)
-                self.close()
-            except Exception as exc:
-                if self.debug:
-                    self.debug.write("EXCEPTION from __exit__: {}".format(exc))
-                raise
+            self.con.__exit__(exc_type, exc_value, traceback)
+            self.close()
 
     def execute(self, sql, parameters=()):
         """Same as :meth:`python:sqlite3.Connection.execute`."""
-        if self.debug:
-            tail = " with {!r}".format(parameters) if parameters else ""
-            self.debug.write("Executing {!r}{}".format(sql, tail))
         try:
             try:
                 return self.con.execute(sql, parameters)
@@ -1085,10 +1029,8 @@ class SqliteDb(SimpleReprMixin):
                         )
             except Exception:
                 pass
-            if self.debug:
-                self.debug.write("EXCEPTION from execute: {}".format(msg))
             raise CoverageException(
-                "Couldn't use data file {!r}: {}".format(self.filename, msg))
+                f"Couldn't use data file {self.filename!r}: {msg}")
 
     def execute_one(self, sql, parameters=()):
         """Execute a statement and return the one row that results.
@@ -1105,15 +1047,10 @@ class SqliteDb(SimpleReprMixin):
         elif len(rows) == 1:
             return rows[0]
         else:
-            raise CoverageException(
-                "Sql {!r} shouldn't return {} rows".format(sql, len(rows)))
+            raise CoverageException(f"Sql {sql!r} shouldn't return {len(rows)} rows")
 
     def executemany(self, sql, data):
         """Same as :meth:`python:sqlite3.Connection.executemany`."""
-        if self.debug:
-            data = list(data)
-            self.debug.write(
-                "Executing many {!r} with {} rows".format(sql, len(data)))
         return self.con.executemany(sql, data)
 
     def executescript(self, script):
