@@ -2,7 +2,9 @@
 
 #include "base.hpp"
 
-class IndexError : public Error, public std::enable_shared_from_this<IndexError> {
+namespace mys {
+
+class IndexError : public Error {
 public:
     String m_message;
     IndexError()
@@ -20,8 +22,10 @@ public:
 
 class __IndexError final : public __Error {
 public:
-    __IndexError(const std::shared_ptr<IndexError>& error)
-        : __Error(static_cast<std::shared_ptr<Error>>(error))
+    __IndexError(const mys::shared_ptr<IndexError>& error)
+        : __Error(static_cast<mys::shared_ptr<Error>>(error))
     {
     }
 };
+
+}
