@@ -2,7 +2,9 @@
 
 #include "base.hpp"
 
-class KeyError : public Error, public std::enable_shared_from_this<KeyError> {
+namespace mys {
+
+class KeyError : public Error {
 public:
     String m_message;
     KeyError()
@@ -20,8 +22,10 @@ public:
 
 class __KeyError final : public __Error {
 public:
-    __KeyError(const std::shared_ptr<KeyError>& error)
-        : __Error(static_cast<std::shared_ptr<Error>>(error))
+    __KeyError(const mys::shared_ptr<KeyError>& error)
+        : __Error(static_cast<mys::shared_ptr<Error>>(error))
     {
     }
 };
+
+}
