@@ -5,6 +5,8 @@ from .definitions import Class
 from .definitions import Function
 from .utils import CompileError
 from .utils import GenericType
+from .utils import Optional
+from .utils import format_mys_type
 from .utils import make_name
 from .utils import make_types_string_parts
 from .utils import mys_to_cpp_type_param
@@ -32,6 +34,13 @@ class SpecializeGenericType:
 
         """
 
+        if isinstance(mys_type, Optional):
+            is_optional = True
+            node = mys_type.node
+            mys_type = mys_type.mys_type
+        else:
+            is_optional = False
+
         if isinstance(mys_type, str):
             if mys_type == self.generic_type:
                 mys_type = self.chosen_type
@@ -46,7 +55,11 @@ class SpecializeGenericType:
             mys_type = tuple(self.replace(item_mys_type)
                              for item_mys_type in mys_type)
         else:
-            raise Exception('generic type not supported')
+            raise Exception(
+                f"generic type '{format_mys_type(mys_type)}' not supported")
+
+        if is_optional:
+            mys_type = Optional(mys_type, node)
 
         return mys_type
 
@@ -194,10 +207,15 @@ def make_generic_name(name, full_name, chosen_types):
 
 def find_chosen_types(node, context):
     types_slice = node.slice
-    chosen_types = [
-        TypeVisitor(context).visit(type_node)
-        for type_node in fix_chosen_types(types_slice, context.source_lines)
-    ]
+    chosen_types = []
+
+    for type_node in fix_chosen_types(types_slice, context.source_lines):
+        chosen_type = TypeVisitor(context).visit(type_node)
+
+        if isinstance(chosen_type, Optional):
+            raise CompileError("generic types cannot be optional", type_node)
+
+        chosen_types.append(chosen_type)
 
     return chosen_types
 
@@ -269,13 +287,28 @@ class TypeVisitor(ast.NodeVisitor):
         if nitems != 1:
             raise CompileError(f"expected 1 type in list, got {nitems}", node)
 
-        return [self.visit(elem) for elem in node.elts]
+        value_type = self.visit(node.elts[0])
+
+        if isinstance(value_type, Optional):
+            raise CompileError("list type cannot be optional", node.elts[0])
+
+        return [value_type]
 
     def visit_Tuple(self, node):
         return tuple(self.visit(elem) for elem in node.elts)
 
     def visit_Dict(self, node):
-        return {self.visit(node.keys[0]): self.visit(node.values[0])}
+        key_type = self.visit(node.keys[0])
+
+        if isinstance(key_type, Optional):
+            raise CompileError("dict key type cannot be optional", node.keys[0])
+
+        value_type = self.visit(node.values[0])
+
+        if isinstance(value_type, Optional):
+            raise CompileError("dict value type cannot be optional", node.values[0])
+
+        return {key_type: value_type}
 
     def visit_Set(self, node):
         nitems = len(node.elts)
@@ -283,10 +316,15 @@ class TypeVisitor(ast.NodeVisitor):
         if nitems != 1:
             raise CompileError(f"expected 1 type in set, got {nitems}", node)
 
-        return {self.visit(node.elts[0])}
+        value_type = self.visit(node.elts[0])
+
+        if isinstance(value_type, Optional):
+            raise CompileError("set type cannot be optional", node.elts[0])
+
+        return {value_type}
 
     def visit_Subscript(self, node):
         if self.visit(node.value) == 'optional':
-            return self.visit(node.slice)
+            return Optional(self.visit(node.slice), node)
         else:
             return add_generic_class(node, self.context)[1]
