@@ -32,7 +32,8 @@ class HeaderVisitor(BaseVisitor):
                  module_definitions,
                  has_main,
                  specialized_classes,
-                 method_comprehensions):
+                 method_comprehensions,
+                 macros):
         super().__init__(Context(module_levels,
                                  {},
                                  specialized_classes,
@@ -56,6 +57,7 @@ class HeaderVisitor(BaseVisitor):
         self.enums = []
         self.members = defaultdict(list)
         self.method_comprehensions = method_comprehensions
+        self.macros = macros
         self.before_namespace = []
 
         for name, trait_definitions in module_definitions.traits.items():
@@ -140,6 +142,9 @@ class HeaderVisitor(BaseVisitor):
 
         for methods_definitions in definitions.methods.values():
             for method in methods_definitions:
+                if method.is_macro:
+                    continue
+
                 for param, default in method.args:
                     if default is None:
                         continue
@@ -228,6 +233,9 @@ class HeaderVisitor(BaseVisitor):
         return [f'extern {cpp_type} {variable.name};']
 
     def visit_function_declaration(self, function):
+        if function.is_macro:
+            return ''
+
         parameters = format_parameters(function.args, self.context)
         return_type = format_return_type(function.returns, self.context)
         code = []
@@ -240,7 +248,7 @@ class HeaderVisitor(BaseVisitor):
             cpp_type = self.mys_to_cpp_type(param.type)
             code.append(format_default(function_name, param.name, cpp_type) + ';')
 
-        if function_name != 'main' and not function.is_test:
+        if function_name != 'main':
             code.append(f'{return_type} {function_name}({parameters});')
 
         return code
@@ -294,9 +302,12 @@ class HeaderVisitor(BaseVisitor):
         self.visit_class_declaration(name, definitions)
 
     def format_early_hpp(self):
+        include_guard = self.namespace.replace('::', '_') + '_EARLY_HPP'
+
         return '\n'.join([
             '// This file was generated by mys. DO NOT EDIT!!!',
-            '#pragma once',
+            f'#ifndef {include_guard}',
+            f'#define {include_guard}',
             f'namespace {self.namespace}',
             '{'
         ] + self.forward + [
@@ -310,19 +321,25 @@ class HeaderVisitor(BaseVisitor):
           + sorted(list(self.imported))
           + self.variables
           + self.functions + [
-            '}'
+            '}',
+            '#endif'
         ])
 
     def format_hpp(self):
+        include_guard = self.namespace.replace('::', '_') + '_HPP'
+
         return '\n'.join([
             '// This file was generated by mys. DO NOT EDIT!!!',
-            '#pragma once',
+            f'#ifndef {include_guard}',
+            f'#define {include_guard}',
             f'#include "{self.module_hpp[:-4]}.early.hpp"'
         ] + sorted(list(self.includes)) + [
             f'namespace {self.namespace}',
             '{'
         ] + self.classes + [
             '}'
+        ] + self.macros + [
+            '#endif'
         ])
 
     def visit_ImportFrom(self, node):
