@@ -11,15 +11,13 @@ class Test(TestCase):
             ast.parse(
                 'VAR1: i32 = 1\n'
                 '_VAR2: [bool] = [True, False]\n'
-                '@enum\n'
-                'class Enum1:\n'
+                'enum Enum1:\n'
                 '    A\n'
                 '    B\n'
                 '    C\n'
                 '    D = 100\n'
                 '    E\n'
-                '@enum(u8)\n'
-                'class _Enum2:\n'
+                'enum _Enum2(u8):\n'
                 '    Aa = 1\n'
                 '    Bb = 5\n'
                 'trait Trait1:\n'
